@@ -16,7 +16,7 @@
 # along with caspo.  If not, see <http://www.gnu.org/licenses/>.import random
 # -*- coding: utf-8 -*-
 import os
-from cellnopt.wrapper import *
+from cellnopt.wrapper import wrapper_cnor as cnor
 
 def compress(pkn, midas):
     """
@@ -31,9 +31,9 @@ def compress(pkn, midas):
     if os.path.exists(temp):
         os.remove(temp)
     
-    cnolist = CNOlist(midas)
-    pknmodel = readSIF(pkn)        
-    model = preprocessing(cnolist, pknmodel, expansion=False)
-    writeSIF(model, temp)
+    cnolist = cnor.CNOlist(midas)
+    pknmodel = cnor.readSIF(pkn)        
+    model = cnor.preprocessing(cnolist, pknmodel, expansion=False)
+    cnor.writeSIF(model, temp)
     
     return temp
\ No newline at end of file
